@@ -146,7 +146,7 @@ def codebook(sig, k):
 """
 Auto-tune the number of codewords (clusters).
 """ 
-def codebook_auto(sig, mink=2 maxk = None):
+def codebook_auto(sig, mink=2, maxk = None):
     if mink < 2:
         raise Exception('mink must be at least 2')
     if maxk is None:
